import { SpreadsheetVisualDataBase } from "./SpreadsheetVisualDataBase";
import { IEnumerable, Type } from "igniteui-angular-core";
import { RectData } from "igniteui-angular-core";
import { PrimitiveVisualDataList } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { ColorData } from "igniteui-angular-core";
/**
 * Represents the visual data for the spreadsheet.
 */
export declare class SpreadsheetVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _tabArea;
    /**
     * Returns or sets the visual data for the area in the spreadsheet that contains the sheet tab items
     */
    get tabArea(): SpreadsheetTabItemAreaVisualData;
    set tabArea(a: SpreadsheetTabItemAreaVisualData);
    private _cellAreas;
    /**
     * Returns or sets the visual data for the cell areas in the spreadsheet
     */
    get cellAreas(): SpreadsheetCellAreaVisualDataList;
    set cellAreas(a: SpreadsheetCellAreaVisualDataList);
    private _rowHeaderAreas;
    /**
     * Returns or sets the visual data for the row header areas in the spreadsheet
     */
    get rowHeaderAreas(): SpreadsheetHeaderAreaVisualDataList;
    set rowHeaderAreas(a: SpreadsheetHeaderAreaVisualDataList);
    private _columnHeaderAreas;
    /**
     * Returns or sets the visual data for the column header areas in the spreadsheet
     */
    get columnHeaderAreas(): SpreadsheetHeaderAreaVisualDataList;
    set columnHeaderAreas(a: SpreadsheetHeaderAreaVisualDataList);
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
    /**
     * @hidden
     */
    static _g(a: any): string;
    /**
     * @hidden
     */
    static _f(a: IEnumerable): string;
    /**
     * @hidden
     */
    static _h(a: string[], b: any[]): string;
}
/**
 * Represents the visual data for a row or column header area within the spreadsheet
 */
export declare class SpreadsheetHeaderAreaVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _relativeBounds;
    /**
     * The position of the area within the containing visual.
     */
    get relativeBounds(): RectData;
    set relativeBounds(a: RectData);
    private _items;
    /**
     * The visual information about the items in the header
     */
    get items(): SpreadsheetRowColumnVisualDataList;
    set items(a: SpreadsheetRowColumnVisualDataList);
    private _shapes;
    /**
     * The visual shape data of the header area.
     */
    get shapes(): PrimitiveVisualDataList;
    set shapes(a: PrimitiveVisualDataList);
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of row or column header areas within the spreadsheet
 */
export declare class SpreadsheetHeaderAreaVisualDataList extends List$1<SpreadsheetHeaderAreaVisualData> {
    static $t: Type;
    constructor();
}
/**
 * Represents the visual data for a cell area within the spreadsheet
 */
export declare class SpreadsheetCellAreaVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _relativeBounds;
    /**
     * The position of the area within the containing visual.
     */
    get relativeBounds(): RectData;
    set relativeBounds(a: RectData);
    private _columns;
    /**
     * The visual information about the columns for the cells
     */
    get columns(): SpreadsheetRowColumnVisualDataList;
    set columns(a: SpreadsheetRowColumnVisualDataList);
    private _rows;
    /**
     * The visual information about the rows for the cells
     */
    get rows(): SpreadsheetRowColumnVisualDataList;
    set rows(a: SpreadsheetRowColumnVisualDataList);
    private _shapes;
    /**
     * The visual shape data of the header area.
     */
    get shapes(): PrimitiveVisualDataList;
    set shapes(a: PrimitiveVisualDataList);
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of cell areas within the spreadsheet
 */
export declare class SpreadsheetCellAreaVisualDataList extends List$1<SpreadsheetCellAreaVisualData> {
    static $t: Type;
    constructor();
}
/**
 * Represents the visual data for a row or column within the spreadsheet
 */
export declare class SpreadsheetRowColumnVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    private _index;
    /**
     * The index of the associated row or column.
     */
    get index(): number;
    set index(a: number);
    private _offset;
    /**
     * The start offset of the row or column within the containing visual.
     */
    get offset(): number;
    set offset(a: number);
    private _extent;
    /**
     * The extent of the row or column within the containing visual.
     */
    get extent(): number;
    set extent(a: number);
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of row or column headers within the spreadsheet
 */
export declare class SpreadsheetRowColumnVisualDataList extends List$1<SpreadsheetRowColumnVisualData> {
    static $t: Type;
    constructor();
}
/**
 * Represents the visual data for the area containing the sheet tabs
 */
export declare class SpreadsheetTabItemAreaVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _relativeBounds;
    /**
     * The position of the area within the containing visual.
     */
    get relativeBounds(): RectData;
    set relativeBounds(a: RectData);
    private _tabs;
    /**
     * The visual information about the sheet tab items
     */
    get tabs(): SpreadsheetTabVisualDataList;
    set tabs(a: SpreadsheetTabVisualDataList);
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a sheet tab within the spreadsheet
 */
export declare class SpreadsheetTabVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    private _sheetIndex;
    /**
     * The index of the associated Sheet.
     */
    get sheetIndex(): number;
    set sheetIndex(a: number);
    private _color;
    /**
     * The color associated with the sheet.
     */
    get color(): ColorData;
    set color(a: ColorData);
    private _isActive;
    /**
     * If the sheet is active
     */
    get isActive(): boolean;
    set isActive(a: boolean);
    private _isEditing;
    /**
     * If the sheet is in edit mode
     */
    get isEditing(): boolean;
    set isEditing(a: boolean);
    private _isProtected;
    /**
     * If the sheet is protected
     */
    get isProtected(): boolean;
    set isProtected(a: boolean);
    private _isSelected;
    /**
     * If the sheet is selected
     */
    get isSelected(): boolean;
    set isSelected(a: boolean);
    private _relativeBounds;
    /**
     * The position of the tab relative to the tab area.
     */
    get relativeBounds(): RectData;
    set relativeBounds(a: RectData);
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of sheet tabs within the spreadsheet
 */
export declare class SpreadsheetTabVisualDataList extends List$1<SpreadsheetTabVisualData> {
    static $t: Type;
    constructor();
}
