import { OnDestroy, EventEmitter, Injector, ComponentFactoryResolver, AfterContentInit, Renderer2, NgZone, ViewContainerRef } from '@angular/core';
import { IgPoint } from "igniteui-angular-core";
import { Spreadsheet } from './Spreadsheet';
import { SpreadsheetAction } from './SpreadsheetAction';
import { SpreadsheetCell } from './SpreadsheetCell';
import { SpreadsheetCellEditMode } from './SpreadsheetCellEditMode';
import { SpreadsheetCellSelectionMode } from './SpreadsheetCellSelectionMode';
import { SpreadsheetChartAdapterBase } from './SpreadsheetChartAdapterBase';
import { SpreadsheetEnterKeyNavigationDirection } from './SpreadsheetEnterKeyNavigationDirection';
import { SpreadsheetPane } from './SpreadsheetPane';
import { SpreadsheetSelection } from './SpreadsheetSelection';
import { SpreadsheetCellRangeFormat } from './SpreadsheetCellRangeFormat';
import { WorksheetTable } from "igniteui-angular-excel";
import { Worksheet } from "igniteui-angular-excel";
import { Workbook } from "igniteui-angular-excel";
import { UndoManager } from './UndoManager';
import { IgxSpreadsheetActionExecutedEventArgs } from './igx-spreadsheet-action-executed-event-args';
import { IgxSpreadsheetActionExecutingEventArgs } from './igx-spreadsheet-action-executing-event-args';
import { IgxSpreadsheetActiveCellChangedEventArgs } from './igx-spreadsheet-active-cell-changed-event-args';
import { IgxSpreadsheetActivePaneChangedEventArgs } from './igx-spreadsheet-active-pane-changed-event-args';
import { IgxSpreadsheetActiveTableChangedEventArgs } from './igx-spreadsheet-active-table-changed-event-args';
import { IgxSpreadsheetActiveWorksheetChangedEventArgs } from './igx-spreadsheet-active-worksheet-changed-event-args';
import { IgxSpreadsheetContextMenuOpeningEventArgs } from './igx-spreadsheet-context-menu-opening-event-args';
import { IgxSpreadsheetEditModeExitingEventArgs } from './igx-spreadsheet-edit-mode-exiting-event-args';
import { IgxSpreadsheetEditModeExitedEventArgs } from './igx-spreadsheet-edit-mode-exited-event-args';
import { IgxSpreadsheetEditModeEnteringEventArgs } from './igx-spreadsheet-edit-mode-entering-event-args';
import { IgxSpreadsheetEditModeEnteredEventArgs } from './igx-spreadsheet-edit-mode-entered-event-args';
import { IgxSpreadsheetEditModeValidationErrorEventArgs } from './igx-spreadsheet-edit-mode-validation-error-event-args';
import { IgxSpreadsheetEditRangePasswordNeededEventArgs } from './igx-spreadsheet-edit-range-password-needed-event-args';
import { IgxSpreadsheetHyperlinkExecutingEventArgs } from './igx-spreadsheet-hyperlink-executing-event-args';
import { IgxSpreadsheetSelectionChangedEventArgs } from './igx-spreadsheet-selection-changed-event-args';
import { IgxSpreadsheetUserPromptDisplayingEventArgs } from './igx-spreadsheet-user-prompt-displaying-event-args';
import { IgxSpreadsheetWorkbookDirtiedEventArgs } from './igx-spreadsheet-workbook-dirtied-event-args';
import * as i0 from "@angular/core";
/**
 * Custom control that displays one or more worksheets.
*/
export declare class IgxSpreadsheetComponent implements AfterContentInit, OnDestroy {
    private _renderer;
    private _elRef;
    private _ngZone;
    private _componentFactoryResolver;
    private _injector;
    _dynamicContent: ViewContainerRef;
    private _height;
    private _width;
    set height(value: string);
    get height(): string;
    set width(value: string);
    get width(): string;
    private _container;
    constructor(_renderer: Renderer2, _elRef: ViewContainerRef, _ngZone: NgZone, _componentFactoryResolver: ComponentFactoryResolver, _injector: Injector);
    ngOnDestroy(): void;
    private _wrapper;
    protected createImplementation(): Spreadsheet;
    private _spreadsheet;
    private _createContainer;
    ngAfterContentInit(): void;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
    protected _implementation: any;
    /**
     * @hidden
     */
    get i(): Spreadsheet; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgxSpreadsheetComponent;
    /**
     * Returns an array of the panes for the activeWorksheet.
    */
    get panes(): SpreadsheetPane[];
    /**
     * Returns or sets a boolean indicating whether the scroll lock key is toggled.
     * This property is used when certain keys are pressed while the control has focus. For example
     * if an arrow key is pressed while the scroll lock is enabled the cell area will be scrolled rather than changing
     * the active cell.
     * Note:
     * This property is not maintained/changed by the control. It is just queried when
     * performing actions that consider whether the scroll lock is enabled.
    */
    get isScrollLocked(): boolean;
    set isScrollLocked(v: boolean);
    static ngAcceptInputType_isScrollLocked: boolean | string;
    /**
     * Returns or sets the active cell within the selected worksheet.
    */
    get activeCell(): SpreadsheetCell;
    set activeCell(v: SpreadsheetCell);
    /**
     * Returns an object that represents the pane with the focus.
    */
    get activePane(): SpreadsheetPane;
    set activePane(v: SpreadsheetPane);
    /**
     * Returns an object that represents the current selection of the
     * activePane.
    */
    get activeSelection(): SpreadsheetSelection;
    set activeSelection(v: SpreadsheetSelection);
    /**
     * Returns an object used to get the formatting of the
     * activeCell and where modifications are applied to the entire
     * activeSelection.
     * Any changes made to this object will affect all the objects in the selection. So for example, the
     * Font.Name may return "Arial" because the active cell has that as its resolved font name even though the other
     * cells are using a different font but if you set the Font.Name of this object to "Arial" then all the objects
     * affected by the selection will have their Font.Name updated to that value.
    */
    get activeSelectionCellRangeFormat(): SpreadsheetCellRangeFormat;
    /**
     * Returns the
     * ig.excel.WorksheetTable associated with the
     * activeCell of the
     * activeWorksheet.
    */
    get activeTable(): WorksheetTable;
    set activeTable(v: WorksheetTable);
    /**
     * Returns or sets the Worksheet from the
     * workbook whose content should be displayed within the control.
    */
    get activeWorksheet(): Worksheet;
    set activeWorksheet(v: Worksheet);
    /**
     * Returns or sets a boolean indicating whether the spreadsheet allows adding worksheets.
    */
    get allowAddWorksheet(): boolean;
    set allowAddWorksheet(v: boolean);
    static ngAcceptInputType_allowAddWorksheet: boolean | string;
    /**
     * Returns or sets a boolean indicating whether the spreadsheet allows deleting worksheets.
    */
    get allowDeleteWorksheet(): boolean;
    set allowDeleteWorksheet(v: boolean);
    static ngAcceptInputType_allowDeleteWorksheet: boolean | string;
    /**
     * Returns or sets a boolean indicating if the grid lines are displayed in the selected worksheets.
    */
    get areGridlinesVisible(): boolean;
    set areGridlinesVisible(v: boolean);
    static ngAcceptInputType_areGridlinesVisible: boolean | string;
    /**
     * Returns or sets a boolean indicating if the row and column headers are displayed for the selected worksheets.
    */
    get areHeadersVisible(): boolean;
    set areHeadersVisible(v: boolean);
    static ngAcceptInputType_areHeadersVisible: boolean | string;
    /**
     * Returns an enumeration used to indicate the current edit mode state.
    */
    get cellEditMode(): SpreadsheetCellEditMode;
    set cellEditMode(v: SpreadsheetCellEditMode);
    /**
     * Returns or sets the object that will provide the chart visualization for display within the
     * Spreadsheet
     * By default charts are not displayed within the spreadsheet. To display charts one should set this
     * property to an instance of a
     * SpreadsheetChartAdapter
     * which is in a separate reference since it relies upon
     * the chart and other data visualization controls.
    */
    get chartAdapter(): SpreadsheetChartAdapterBase;
    set chartAdapter(v: SpreadsheetChartAdapterBase);
    /**
     * Returns or sets an enumeration indicating the direction of the cell adjacent to the
     * activeCell that should be activated when the enter key is pressed.
     * This property is only used if the
     * isEnterKeyNavigationEnabled is set to true. Also, the reverse direction is
     * navigated when Shift + Enter are pressed.
    */
    get enterKeyNavigationDirection(): SpreadsheetEnterKeyNavigationDirection;
    set enterKeyNavigationDirection(v: SpreadsheetEnterKeyNavigationDirection);
    /**
     * Returns or sets the number of decimal places by which a whole number typed in during edit mode should be adjusted when
     * isFixedDecimalEnabled is true
    */
    get fixedDecimalPlaceCount(): number;
    set fixedDecimalPlaceCount(v: number);
    static ngAcceptInputType_fixedDecimalPlaceCount: number | string;
    /**
     * Returns or sets a boolean indicating whether the adjacent cell indicated by the
     * enterKeyNavigationDirection should be navigated to when the enter key is pressed.
    */
    get isEnterKeyNavigationEnabled(): boolean;
    set isEnterKeyNavigationEnabled(v: boolean);
    static ngAcceptInputType_isEnterKeyNavigationEnabled: boolean | string;
    /**
     * Returns or sets a boolean indicating whether a fixed decimal place is automatically added when a whole number is entered while in edit mode.
    */
    get isFixedDecimalEnabled(): boolean;
    set isFixedDecimalEnabled(v: boolean);
    static ngAcceptInputType_isFixedDecimalEnabled: boolean | string;
    /**
     * Returns or sets a boolean indicating if the formula bar is displayed within the
     * Spreadsheet.
    */
    get isFormulaBarVisible(): boolean;
    set isFormulaBarVisible(v: boolean);
    static ngAcceptInputType_isFormulaBarVisible: boolean | string;
    /**
     * Returns a boolean indicating if the control is currently editing the value of the
     * activeCell
    */
    get isInEditMode(): boolean;
    set isInEditMode(v: boolean);
    static ngAcceptInputType_isInEditMode: boolean | string;
    /**
     * Returns or sets a boolean indicating whether the control is in "End mode".
     * End mode is a mode that affects certain keyboard navigation such as navigating with the arrow keys. For example when in
     * end mode and one presses the right arrow, the
     * activeCell will be changed to be the first cell to the right of the current ActiveCell
     * that has a value (even if the value is ""). If there were no cells to the right with a value then it would activate the right most cell in that row. End
     * mode will end automatically such as when one presses an arrow key.
    */
    get isInEndMode(): boolean;
    set isInEndMode(v: boolean);
    static ngAcceptInputType_isInEndMode: boolean | string;
    /**
     * Returns a boolean indicating if the user is currently editing the name of the active worksheet.
    */
    get isRenamingWorksheet(): boolean;
    set isRenamingWorksheet(v: boolean);
    static ngAcceptInputType_isRenamingWorksheet: boolean | string;
    /**
     * Returns or sets a boolean indicating whether undo is enabled for the control.
    */
    get isUndoEnabled(): boolean;
    set isUndoEnabled(v: boolean);
    static ngAcceptInputType_isUndoEnabled: boolean | string;
    /**
     * Returns or sets the width of the name box within the formula bar.
    */
    get nameBoxWidth(): number;
    set nameBoxWidth(v: number);
    static ngAcceptInputType_nameBoxWidth: number | string;
    /**
     * Returns or sets a value indicating how the selection is updated when interacting with the cells via the mouse or keyboard.
    */
    get selectionMode(): SpreadsheetCellSelectionMode;
    set selectionMode(v: SpreadsheetCellSelectionMode);
    /**
     * Returns or sets an array of the Worksheets whose tabs are selected.
    */
    get selectedWorksheets(): Worksheet[];
    set selectedWorksheets(v: Worksheet[]);
    static ngAcceptInputType_selectedWorksheets: Worksheet[] | string;
    /**
     * Returns or sets the UndoManager.
     * Note:
     * this property can not be set to null.
    */
    get undoManager(): UndoManager;
    set undoManager(v: UndoManager);
    /**
     * Returns or sets the position of the screen tip used to display the input message for the data validation rule associated with the active cell.
    */
    get validationInputMessagePosition(): IgPoint;
    set validationInputMessagePosition(v: IgPoint);
    static ngAcceptInputType_validationInputMessagePosition: IgPoint | string;
    /**
     * Returns or sets the
     * workbook whose information is displayed in the control.
    */
    get workbook(): Workbook;
    set workbook(v: Workbook);
    /**
     * Returns or sets the magnification of the selected worksheets.
    */
    get zoomLevel(): number;
    set zoomLevel(v: number);
    static ngAcceptInputType_zoomLevel: number | string;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Notifies the spreadsheet that the container object has been resized.
    
    */
    containerResized(): void;
    /**
     * Executes the specified action.
    
    * @param action  * Identifies the action to be performed.
    */
    executeAction(action: SpreadsheetAction): boolean;
    /**
     * Forces the spreadsheet to synchronously perform any deferred work.
    
    */
    flush(): void;
    /**
     * Notifies the spreadsheet that style information used for rendering may have been updated.
    
    */
    styleUpdated(): void;
    /**
     * Returns an object with information about the visual state of the spreadsheet.
    
    */
    exportVisualData(): any;
    private _contextMenuOpening;
    /**
     * Invoked when a contextmenu is being opened for the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.menuArea" argType="string" Get the [area](ig.spreadsheet.SpreadsheetContextMenuArea) for which the menu is being displayed.
    */
    get contextMenuOpening(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetContextMenuOpeningEventArgs;
    }>;
    private _ActionExecuted;
    /**
     * Invoked when an action is executed on the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Gets the [action](ig.spreadsheet.SpreadsheetAction) that was executed.
    */
    get ActionExecuted(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetActionExecutedEventArgs;
    }>;
    private _ActionExecuting;
    /**
     * Invoked when an action is about to be executed by the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Gets the [action](ig.spreadsheet.SpreadsheetAction) that is about to be executed.
    */
    get ActionExecuting(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetActionExecutingEventArgs;
    }>;
    private _activeCellChanged;
    /**
     * Invoked when the
     * activeCell of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldValue" argType="string" Gets the previous active cell.
     * eventArgument="ui.newValue" argType="string" Gets the current active cell.
    */
    get activeCellChanged(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetActiveCellChangedEventArgs;
    }>;
    private _activePaneChanged;
    /**
     * Invoked when the
     * activePane of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActivePane" argType="object" Gets the previous active [pane](ig.spreadsheet.SpreadsheetPane).
     * eventArgument="ui.newActivePane" argType="object" Gets the current active [pane](ig.spreadsheet.SpreadsheetPane).
     * eventArgument="ui.activeCell" argType="string" Gets the active cell of the new active pane or null if there is no active pane.
     * eventArgument="ui.visibleRange" argType="string" Gets the current visible range of the new active pane or null if there is no active pane.
    */
    get activePaneChanged(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetActivePaneChangedEventArgs;
    }>;
    private _activeTableChanged;
    /**
     * Invoked when the
     * activeTable of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActiveTable" argType="object" Gets the previous active [Table](ig.excel.WorksheetTable).
     * eventArgument="ui.newActiveTable" argType="object" Gets the current active [Table](ig.excel.WorksheetTable).
    */
    get activeTableChanged(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetActiveTableChangedEventArgs;
    }>;
    private _activeWorksheetChanged;
    /**
     * Invoked when the
     * activeWorksheet of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActiveWorksheet" argType="object" Gets the previous active [worksheet](ig.excel.Worksheet).
     * eventArgument="ui.oldActiveWorksheetName" argType="string" Gets the name of the previous active worksheet or null if oldActiveWorksheet is null.
     * eventArgument="ui.newActiveWorksheet" argType="object" Gets the current active [worksheet](ig.excel.Worksheet).
     * eventArgument="ui.newActiveWorksheetName" argType="string" Gets the name of the new active worksheet or null if newActiveWorksheet is null.
    */
    get activeWorksheetChanged(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetActiveWorksheetChangedEventArgs;
    }>;
    private _editModeExiting;
    /**
     * Invoked when the
     * Spreadsheet is about to end the in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.acceptChanges" argType="bool" Get or set a boolean indicating whether the changes will be made to the cell's value when edit mode ends.
     * eventArgument="ui.canCancel" argType="bool" Get a boolean indicating if the edit mode is being forced to exit edit mode in which case it cannot be cancelled.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is exiting edit mode.
     * eventArgument="ui.editText" argType="string" Gets the edit text that will be used to update the cell(s).
    */
    get editModeExiting(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetEditModeExitingEventArgs;
    }>;
    private _editModeExited;
    /**
     * Invoked when the
     * Spreadsheet has ended the in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control has exited edit mode.
    */
    get editModeExited(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetEditModeExitedEventArgs;
    }>;
    private _editModeEntering;
    /**
     * Invoked when the
     * Spreadsheet is about to start in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is going into edit mode.
    */
    get editModeEntering(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetEditModeEnteringEventArgs;
    }>;
    private _editModeEntered;
    /**
     * Invoked when the
     * Spreadsheet has started in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control has entered edit mode.
    */
    get editModeEntered(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetEditModeEnteredEventArgs;
    }>;
    private _editModeValidationError;
    /**
     * Invoked when the
     * Spreadsheet is exiting edit mode and the new value for the
     * activeCell is not valid based on the criteria of that cell's
     * ig.excel.DataValidationRule.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Get or set the [action](ig.spreadsheet.SpreadsheetEditModeValidationErrorAction)  to take in response to the failed validation.
     * eventArgument="ui.canStayInEditMode" argType="bool" Get a boolean indicating whether the cell is allowed to stay in edit mode.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is in edit mode.
     * eventArgument="ui.validationRule" argType="string" Get the [rule](ig.excel.DataValidationRule) which failed validation.
     * The EditModeValidationError is raised while exiting edit mode if the new value for the
     * activeCell is not valid based on the criteria of that cell's
     * ig.excel.DataValidationRule.
     * Since the rule needs to evaluate the value of the cell and potentially other cell's in the Worksheet, the value is first applied to the cell(s) and then is validated. By default if the event is not handled and the
     * showErrorMessageForInvalidValue is true, a message box will be displayed to the end user to determine what action to take. One can handle this event and specify the action that should
     * be taken using the action.
     * Note:
     * The validation rule will not be evaluated if edit mode is being cancelled such as when the user presses Escape to cancel edit.
     * Note:
     * The action will default to
     * AcceptChange
     * if the ShowErrorMessageForInvalidValue of the validationRule is false; otherwise it will default to
     * ShowPrompt
     * .
     * Note:
     * Like Microsoft Excel, only the validation rule of the active cell is considered even if the update is affecting other cells in the selection.
    */
    get editModeValidationError(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetEditModeValidationErrorEventArgs;
    }>;
    private _editRangePasswordNeeded;
    /**
     * Invoked when the
     * Spreadsheet is performing an operation on a protected Worksheet and there is a single range that may be unlocked to allow the operation to be performed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.ranges" argType="array" Get an array of [protected range](ig.excel.WorksheetProtectedRange) objects that should be unlocked.
     * eventArgument="ui.unprotect" argType="object" Get a parameterless function that may be invoked to unlock the associated ranges.
    */
    get editRangePasswordNeeded(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetEditRangePasswordNeededEventArgs;
    }>;
    private _hyperlinkExecuting;
    /**
     * Invoked when a hyperlink is being followed in the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.hyperlink" argType="object" Get the [hyperlink](ig.excel.WorksheetHyperlink) to be executed.
    */
    get hyperlinkExecuting(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetHyperlinkExecutingEventArgs;
    }>;
    private _selectionChanged;
    /**
     * Invoked when the selection for a
     * ig.spreadsheet.SpreadsheetPane of the
     * Spreadsheet is changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.pane" argType="object" Get the [pane](ig.spreadsheet.SpreadsheetPane) for which the selection has changed.
    */
    get selectionChanged(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetSelectionChangedEventArgs;
    }>;
    private _userPromptDisplaying;
    /**
     * Invoked when the user will be prompted with a message regarding an operation that is being performed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.canCancel" argType="bool" Get a boolean indicating if the operation that triggered the prompt can be cancelled.
     * eventArgument="ui.displayMessage" argType="bool" Get a boolean indicating if a message will be displayed to the end user.
     * eventArgument="ui.exception" argType="object" Gets the exception for the error, if there was one.
     * eventArgument="ui.message" argType="string" Get or set the message that will be displayed.
     * eventArgument="ui.trigger" argType="string" Get the [action](ig.spreadsheet.SpreadsheetUserPromptTrigger) that caused the prompt to be displayed.
    */
    get userPromptDisplaying(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetUserPromptDisplayingEventArgs;
    }>;
    private _workbookDirtied;
    /**
     * Invoked when a change has been made to the
     * workbook that might require a save.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * Note:
     * This event is invoked asynchronously with regards to the change(s) that
     * have occurred. Also some changes alone are not considered to dirty the Workbook even though it
     * does change state on the Workbook or one of its subobjects. An example of that would be a zoom
     * type operation (e.g. changing the
     * magnificationInNormalView).
    */
    get workbookDirtied(): EventEmitter<{
        sender: any;
        args: IgxSpreadsheetWorkbookDirtiedEventArgs;
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxSpreadsheetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxSpreadsheetComponent, "igx-spreadsheet", never, { "height": "height"; "width": "width"; "isScrollLocked": "isScrollLocked"; "activeCell": "activeCell"; "activePane": "activePane"; "activeSelection": "activeSelection"; "activeTable": "activeTable"; "activeWorksheet": "activeWorksheet"; "allowAddWorksheet": "allowAddWorksheet"; "allowDeleteWorksheet": "allowDeleteWorksheet"; "areGridlinesVisible": "areGridlinesVisible"; "areHeadersVisible": "areHeadersVisible"; "cellEditMode": "cellEditMode"; "chartAdapter": "chartAdapter"; "enterKeyNavigationDirection": "enterKeyNavigationDirection"; "fixedDecimalPlaceCount": "fixedDecimalPlaceCount"; "isEnterKeyNavigationEnabled": "isEnterKeyNavigationEnabled"; "isFixedDecimalEnabled": "isFixedDecimalEnabled"; "isFormulaBarVisible": "isFormulaBarVisible"; "isInEditMode": "isInEditMode"; "isInEndMode": "isInEndMode"; "isRenamingWorksheet": "isRenamingWorksheet"; "isUndoEnabled": "isUndoEnabled"; "nameBoxWidth": "nameBoxWidth"; "selectionMode": "selectionMode"; "selectedWorksheets": "selectedWorksheets"; "undoManager": "undoManager"; "validationInputMessagePosition": "validationInputMessagePosition"; "workbook": "workbook"; "zoomLevel": "zoomLevel"; }, { "contextMenuOpening": "contextMenuOpening"; "ActionExecuted": "ActionExecuted"; "ActionExecuting": "ActionExecuting"; "activeCellChanged": "activeCellChanged"; "activePaneChanged": "activePaneChanged"; "activeTableChanged": "activeTableChanged"; "activeWorksheetChanged": "activeWorksheetChanged"; "editModeExiting": "editModeExiting"; "editModeExited": "editModeExited"; "editModeEntering": "editModeEntering"; "editModeEntered": "editModeEntered"; "editModeValidationError": "editModeValidationError"; "editRangePasswordNeeded": "editRangePasswordNeeded"; "hyperlinkExecuting": "hyperlinkExecuting"; "selectionChanged": "selectionChanged"; "userPromptDisplaying": "userPromptDisplaying"; "workbookDirtied": "workbookDirtied"; }, never, never>;
}
